;Trigtogg (Trig toggle) version 2
;Modified by Andy Johnson from Brad Wissel's trigmode program
;Modified portions Copyright 1998 Andy Johnson, Distribute freely

;This program displays an "r" or a degree symbol in the upper right corner
;of the screen at all times.  Pushing Alpha-On switches the mode.  If alphalock
;is on, it will not be disturbed.  If only normal alpha is on, the alpha will
;be cancled.  If lowercase Alpha-On is pressed, the interupt will be temporarly
;disabled, the symbol will still appear, however, until the screen is cleared.  
;Pressing lowercase Alpha-On again will be enabled and the symbol will appear.
;This feature was introduced in version 2

#include asm86.h
#include ti86asm.inc

_user_int_ram EQU $d2fd

;remove the ";" on the second line and put it on the first to display the symbol
;one character to the left, and avoid writing over the run indicator
_plot EQU $FC00+15  ;$FC00 is the first pixel, currently points 15 down from it
;_plot EQU $FC00+14 ;$FC00 is the first pixel, currently points 14 down from it

.org _asm_exec_ram
   res 2,(iy+$23)    ;turn user int off so it won't get called by
                     ;accident before we're ready
   
   ld hl,int         ;copy prog to user int buffer
   ld de,_user_int_ram+1
   ld bc,int_end-int
   ldir
   
   ld a,(_user_int_ram+1)  ;set up checksum byte
   ld hl,_user_int_ram+($28*1)
   add a,(hl)
   ld hl,_user_int_ram+($28*2)
   add a,(hl)
   ld hl,_user_int_ram+($28*3)
   add a,(hl)
   ld hl,_user_int_ram+($28*4)
   add a,(hl)
   ld hl,_user_int_ram+($28*5)
   add a,(hl)
   ld (_user_int_ram),a

   set 2,(iy+$23)    ;turn it on
   ret

int:
 push bc
 push hl
 push af
 ld hl,flag
 bit 1,(hl)							;is routine disabled?
 jr nz,check						;if so, skip over routine

 bit shiftAlpha,(iy+shiftflags)	;check if in alpha mode
 jr z,iconit						;if not, skip over to display routines
 bit onInterrupt,(iy+onflags) ;check if on was pressed
 jr z,iconit						;if not, skip over to display routines
 bit shiftLwrAlph, (iy+shiftflags)	;check if in lowercase
 jr nz,flagswap					;if so, dis/enable interupt
 bit shiftALock,(iy+shiftflags)	;are we in alpha lock?
 jr nz,skip							;if so, don't turn alpha off
 res shiftAlpha,(iy+shiftflags)	;turn alpha mode off
skip:
 bit trigdeg,(iy+trigflags)	;are we in degrees?
 jr z,sdeg							;if so, change to degrees
srad:
 res trigdeg,(iy+trigflags)	;change to radians
 jr iconit							;skip over to display routines
sdeg:
 set trigdeg,(iy+trigflags)	;change to degrees
iconit:
 bit trigdeg,(iy+trigflags) ;check to see how the mode flag is set, 0=radians 1=degrees
 jr z,radians               ;Thanks to Jimmy Mardell.
degrees:
 LD de,degree					;this was part of the trigmode program
 JR drawIt
radians:
 LD de,radian

drawIt:
 ld hl,_plot
 ld b,6 
PutMoreImg:
 ld a,(de)
 inc de
 ld (hl),a
 push de
 ld de,16
 add hl,de
 pop de
 djnz PutMoreImg
 
check:
 bit shiftAlpha,(iy+shiftflags)	;check if in alpha mode
 jr z,ending							;if not, quit
 bit onInterrupt,(iy+onflags) ;check if on was pressed
 jr z,ending						;if not, quit
flagswap:
 bit shiftALock,(iy+shiftflags)	;are we in alpha lock?
 jr nz,flagskip						;if so, don't turn alpha off
 res shiftAlpha,(iy+shiftflags)	;turn alpha mode off
flagskip:
 bit 1,(hl)								;is display enabled?
 jr z,zero								;if so, disable it
 res 1,(hl)								;otherwise, enable display
 jr ending
zero:
 set 1,(hl)								;disable display
ending:
 pop bc
 pop hl
 pop af
 ret

degree equ $-int+_user_int_ram+1
 .db %00000000,%00011000,%00100100
 .db %00100100,%00011000,%00000000

radian equ $-int+_user_int_ram+1
 .db %00000000,%00101100,%00110000
 .db %00100000,%00100000,%00000000

flag equ $-int+_user_int_ram+1
 .db 00

int_end:
          
.END


